Configuring live documents
==========================

Live documents are another type of time-based documents.
In contrast to posters, they are not uplaoded manually,
but automatically updated by some trigger.

Types of live documents are provided by other AlekSIS apps.
All live document types provided by apps can then be configured
from the `Documents` menu.

An example for a live document is an automatically generated
substitution plan, which can be linked to from a website,
or displayed on digital signage.

.. image:: ../_static/create_live_document.png
  :width: 600
  :alt: Create live document

All fields except the slug are provided by the app.
The slug again makes up the stable URL the live document
will be provided under, which can be copied from the live document
list.

The app providing a live document type will take care of
updating the document. A live substitution plan might thus be
re-generated whenever timetable or substitution data changes.
